<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Moniteur système</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Le Moniteur système est un outil pour surveiller la charge du système en temps réel, afficher et contrôler les processus et services exécutés sur votre système.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Cacher les détails</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation>Utilisation globale</translation>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation>Utilisation individuelle</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Lire</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Écrire</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 secondes</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 jours %2 heures %3 minutes</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Utilisation</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Fréquence actuelle</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Fréquence</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Sockets</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Processeurs logiques</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualisation</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>Cache L1i</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>Cache L1d</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>Cache L2</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>Cache L3</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Charge moyenne</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Descripteurs de fichier</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Processus</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Threads</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nom d&apos;hôte</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Type d&apos;OS</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Temps écoulé</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 secondes</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>actif</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>rechargement</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inactif</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>a échoué</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>activation</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>désactivation</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>introuvable</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>mauvais réglage</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erreur</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>fusionné</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>masqué</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>chargé</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>activé</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>désactivé</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statique</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>transitoire</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indirecte</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>activé-runtime</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>masqué</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>généré</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>mort</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-pre</translation>
    </message>
    <message>
        <source>start</source>
        <translation>démarrer</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-post</translation>
    </message>
    <message>
        <source>running</source>
        <translation>en cours d&apos;exécution</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>quittée</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>recharger</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>arrêter</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-post</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>a échoué</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-restart</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>L&apos;utilisation du processeur est supérieure à %1% !</translation>
    </message>
    <message>
        <source>Your memory usage is higher than %1%!</source>
        <translation>L&apos;utilisation de la mémoire est supérieure à %1% !</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Utilisé</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Partagé</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>En cache</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Tampons</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Swap en cache</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Inactif</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Mauvais</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mappé</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Échange total</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Échange gratuit</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Modèle</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Vitesse de lecture</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Vitesse d&apos;écriture</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Capacité</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Secteurs lus</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Lectures/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Secteurs lus/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Lectures accomplies/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Secteurs écrits</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Écritures terminées </translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Écritures accomplies</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Écritures/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Secteurs écrits/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Écritures accomplies/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Afficher les raccourcis</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>La fin de ce processus peut entraîner une perte de données. 
Êtes-vous sur de vouloir continuer ?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Terminer le processus</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>La fin de ce processus peut entraîner une perte de données.
Êtes-vous sur de vouloir continuer ?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forcer la fermeture de cette application peut entraîner une perte de données.
Es-tu sûr de vouloir continuer ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Forcer à quitter</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Fin</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Adresse IP :</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Masque de réseau :</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Broadcast :</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen :</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Portée :</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Type de connexion</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Qualité du lien</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Force du signal</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Niveau de bruit</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Bande passante</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>Paquets RX</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>Octets RX</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>Erreurs RX</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX abandonné</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>Dépassements RX</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>Cadre RX</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>Paquets TX</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>Octets TX</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>Erreurs TX</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>Dépassements TX</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>Transporteur TX</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX abandonné</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Ligne de commande</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Heure de début</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Cliquer sur l&apos;application que vous souhaitez fermer</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Recevoir</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lecture du disque</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Écriture du disque</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Mémoire virtuelle</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Non activé</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Réception</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Téléversement</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Total reçu</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Total envoyé</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envoyer</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disques</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Chargement</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Très élevé</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Élevé</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Faible</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Très faible</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Non valide</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID : %1, Erreur : [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Impossible de modifier la priorité du processus</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mes processus</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tous les processus</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Impossible de suspendre le processus</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Impossible de reprendre le processus</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Impossible de tuer le processus</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Échec de l&apos;envoi du signal au processus</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Échec de la fin du processus</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 applications et %2 processus sont en cours d&apos;exécution)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Pas de réponse</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Barre</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Afficher l&apos;emplacement de la commande</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Terminer le processus</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Reprendre le processus</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Tuer le processus</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Modifier la priorité</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspendre le processus</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Priorité personnalisée</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Changer</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Mémoire</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Écriture du disque</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lecture du disque</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Réception</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Téléversement</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utilisateur</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorité</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Mémoire partagée</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Mémoire virtuelle</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Pas de support</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>System Protection</source>
        <translation>Protection du système</translation>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Afficher les avertissements que l&apos;utilisation dépasse les seuils</translation>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation>Seuil d&apos;avertissement du processeur (%)</translation>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation>Seuil d&apos;avertissement de la mémoire (%)</translation>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation>Intervalle des avertissements (min)</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifications</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Impossible de définir le mode démarrage du service</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Erreur : impossible de définir le type de démarrage du service en raison du sous-processus en panne.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Nom de l&apos;instance de service</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Actualiser</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Démarrer</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Type de démarrage</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Charger</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="vanished">Actif</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Sous</translation>
    </message>
    <message>
        <source>State</source>
        <translation type="vanished">État</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Type de démarrage</translation>
    </message>
    <message>
        <source>Start State</source>
        <translation>État de début</translation>
    </message>
    <message>
        <source>Start Tactic</source>
        <translation>Tactique de début</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation>(Modifiable)</translation>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation>Intervalle : %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Forcer à quitter l&apos;application</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Développer</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Compact</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Processus</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Services</translation>
    </message>
    <message>
        <source>Users</source>
        <translation>Utilisateurs</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <source>Administrator</source>
        <translation>Administrateur </translation>
    </message>
    <message>
        <source>Standard User</source>
        <translation>Utilisateur standard</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <source>Edit account information</source>
        <translation>Éditer les informations du compte</translation>
    </message>
</context>
</TS>